@@ -2,7 +2,7 @@ package Test2::Compare::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.000069';
+our $VERSION = '0.000075';
 
 use Carp qw/confess croak/;
 use Scalar::Util qw/blessed/;
@@ -10,9 +10,6 @@ use Scalar::Util qw/blessed/;
 use Sub::Info qw/sub_info/;
 use Test2::Compare::Delta();
 
-use overload bool => sub { 0 };
-use overload '""' => sub { $_[0] };
-
 sub MAX_CYCLES() { 75 }
 
 use Test2::Util::HashBase qw{builder _file _lines _info called};
@@ -97,7 +94,7 @@ sub run {
     my $got = $exists ? $params{got} : undef;
 
     # Prevent infinite cycles
-    if (defined($got) && ref $got) {
+    if ($got && ref $got) {
         die "Cycle detected in comparison, aborting"
             if $seen->{$got} && $seen->{$got} >= MAX_CYCLES;
         $seen->{$got}++;
@@ -106,7 +103,7 @@ sub run {
     my $ok = $self->verify(%params);
     my @deltas = $ok ? $self->deltas(%params) : ();
 
-    $seen->{$got}-- if defined $got && ref $got;
+    $seen->{$got}-- if $got && ref $got;
 
     return if $ok && !@deltas;
 
