@@ -2,7 +2,7 @@ package Test2::Plugin::BailOnFail;
 use strict;
 use warnings;
 
-our $VERSION = '0.000070';
+our $VERSION = '0.000075';
 
 use Test2::API qw/test2_add_callback_context_release/;
 
@@ -40,7 +40,7 @@ diagnostics they may need.
 
 =head1 SYNOPSIS
 
-    use Test2::Bundle::Extended;
+    use Test2::V0;
     use Test2::Plugin::BailOnFail;
 
     ok(1, "pass");
