@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000069';
+our $VERSION = '0.000075';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -200,7 +200,7 @@ sub D() {
 sub DF() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { defined $_ && ( ! ref $_ && ! $_ ) ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
+        code => sub { defined $_ && ! $_ ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -236,7 +236,7 @@ sub F() {
 sub FDNE() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { defined $_ && ( ref $_ || $_ ) ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
+        code => sub { $_ ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -245,7 +245,7 @@ sub FDNE() {
 sub T() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { defined $_ && ( ref $_ || $_ ) ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
+        code => sub { $_ ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -328,7 +328,7 @@ sub string($;@) {
 }
 
 sub filter_items(&) {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support filters"
         unless $build->can('add_filter');
@@ -340,7 +340,7 @@ sub filter_items(&) {
 }
 
 sub all_items {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support all-items"
         unless $build->can('add_for_each');
@@ -352,7 +352,7 @@ sub all_items {
 }
 
 sub all_keys {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support all-keys"
         unless $build->can('add_for_each_key');
@@ -365,7 +365,7 @@ sub all_keys {
 
 *all_vals = *all_values;
 sub all_values {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support all-values"
         unless $build->can('add_for_each_val');
@@ -378,7 +378,7 @@ sub all_values {
 
 
 sub end() {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -390,7 +390,7 @@ sub end() {
 }
 
 sub etc() {
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -403,7 +403,7 @@ sub etc() {
 
 my $_call = sub {
     my ($name, $expect, $context, $func_name) = @_;
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support method calls"
         unless $build->can('add_call');
@@ -430,7 +430,7 @@ sub call_hash($$) { $_call->(@_,'hash','call_hash') }
 
 sub prop($$) {
     my ($name, $expect) = @_;
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support meta-checks"
         unless $build->can('add_prop');
@@ -453,7 +453,7 @@ sub item($;$) {
     my @args   = @_;
     my $expect = pop @args;
 
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support array item checks"
         unless $build->can('add_item');
@@ -474,7 +474,7 @@ sub item($;$) {
 sub field($$) {
     my ($name, $expect) = @_;
 
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' does not support hash field checks"
         unless $build->can('add_field');
@@ -496,7 +496,7 @@ sub field($$) {
 sub check($) {
     my ($check) = @_;
 
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
 
     croak "'$build' is not a check-set"
         unless $build->can('add_check');
@@ -543,7 +543,7 @@ sub fail_events($;$) {
 
     return ($event, $diag) if defined wantarray;
 
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
     $build->add_item($event);
     $build->add_item($diag);
 }
@@ -600,7 +600,7 @@ sub event($;$) {
 
     return $event if defined wantarray;
 
-    defined( my $build = get_build() ) or croak "No current build!";
+    my $build = get_build() or croak "No current build!";
     $build->add_item($event);
 }
 
